==> openwebbeans-impl-1.1.1-sources.jar: org/apache/webbeans/util/OpenWebBeansClassLoaderProvider.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements. See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership. The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License. You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied. See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
package org.apache.webbeans.util;

import javassist.util.proxy.ProxyFactory;

/**
 * Allows to switch to the {@link ClassLoader} of the current thread
 */
public class OpenWebBeansClassLoaderProvider implements ProxyFactory.ClassLoaderProvider
{
    private ProxyFactory.ClassLoaderProvider wrapped;

    private static ThreadLocal<Boolean> useCurrentClassLoader = new ThreadLocal<Boolean>();

    OpenWebBeansClassLoaderProvider()
    {
        this.wrapped = ProxyFactory.classLoaderProvider;
    }

    public void useCurrentClassLoader()
    {
        useCurrentClassLoader.set(true);
    }

    public void reset()
    {
        useCurrentClassLoader.set(null);
        useCurrentClassLoader.remove();
    }

    @Override
    public ClassLoader get(ProxyFactory proxyFactory)
    {
        if(!Boolean.TRUE.equals(useCurrentClassLoader.get()))
        {
            return wrapped.get(proxyFactory);
        }
        return Thread.currentThread().getContextClassLoader();
    }
}

==> openwebbeans-impl-1.1.4-sources.jar: org/apache/webbeans/util/OpenWebBeansClassLoaderProvider.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements. See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership. The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License. You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied. See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
package org.apache.webbeans.util;

import javassist.util.proxy.ProxyFactory;

/**
 * Allows to switch to the {@link ClassLoader} of the current thread
 */
public class OpenWebBeansClassLoaderProvider implements ProxyFactory.ClassLoaderProvider
{
    private ProxyFactory.ClassLoaderProvider wrapped;

    private static ThreadLocal<Boolean> useCurrentClassLoader = new ThreadLocal<Boolean>();

    OpenWebBeansClassLoaderProvider()
    {
        wrapped = ProxyFactory.classLoaderProvider;
    }

    public void useCurrentClassLoader()
    {
        useCurrentClassLoader.set(true);
    }

    public void reset()
    {
        useCurrentClassLoader.set(null);
        useCurrentClassLoader.remove();
    }

    public ClassLoader get(ProxyFactory proxyFactory)
    {
        if(!Boolean.TRUE.equals(useCurrentClassLoader.get()))
        {
            return wrapped.get(proxyFactory);
        }
        return Thread.currentThread().getContextClassLoader();
    }
}
